@@ -107,7 +107,18 @@ def check_input(args):
     return (seqFile, hmmpath, corepath, searchpath, annopath)
 
 
+def get_seed_id_from_fa(core_fa, refspec):
+    """ Get seed ID from core ortholog fasta file
+    (used if --reuseCore option is specified)
+    """
+    core_seqs = SeqIO.to_dict((SeqIO.parse(open(core_fa), 'fasta')))
+    core_ids = core_seqs.keys()
+    seed_id = [s for s in core_ids if refspec in s][0].split('|')[-1]
+    return(seed_id)
+
+
 def identify_seed_id(seqFile, refspec, corepath, debug, silentOff):
+    """ Identify seed ID in reference protein set using BLAST """
     refspec_db = '%s/%s/%s' % (corepath, refspec, refspec)
     # first check if input seed ID existiert in refspec genome
     refspec_fa = fasta_fn.read_fasta('%s.fa' % refspec_db)
@@ -119,7 +130,7 @@ def identify_seed_id(seqFile, refspec, corepath, debug, silentOff):
         except:
             output_fn.print_debug(debug, 'Identify seed ID', 'Input seed ID not found!')
     # otherwise, perform blast search
-    blast_xml = blast_fn.do_blastsearch(seqFile, refspec_db)
+    blast_xml = blast_fn.do_blastsearch(seqFile, refspec_db, evalBlast = 0.001)
     blast_out = blast_fn.parse_blast_xml(blast_xml)
     for hit in blast_out['hits']:
         if blast_out['hits'][hit]['align_len'] == blast_out['query_len']:
