@@ -57,25 +57,45 @@ def get_seed_name(seedFile):
     return(seqName)
 
 
-def compile_core(core_options, other_options, seeds, inFol, cpus, outpath, silentOff):
+def create_core_jobs(args):
+    (seed, core_options, other_options, inFol, outpath, silentOff) = args
+    (coreArgs, orthoCoreArgs, otherCoreArgs) = core_options
+    (refspec, reuseCore, forceCore, pathArgs, debug) = other_options
+    (outpath, hmmpath, corepath, searchpath, annopath) = pathArgs
+    seqFile = ('%s/%s' % (inFol, seed))
+    seqName = get_seed_name(seed)
+    if not os.path.exists('%s/core_orthologs/%s/hmm_dir/%s.hmm' % (outpath, seqName, seqName)) or forceCore == True:
+        seed_id = prepare_fn.identify_seed_id(seqFile, refspec, corepath, debug, silentOff)
+        if not seed_id == 'None':
+            return([seqFile, seqName, refspec, seed_id,
+                        reuseCore, forceCore, coreArgs, pathArgs, orthoCoreArgs,
+                        otherCoreArgs, debug])
+        else:
+            print(f'WARNING: Cannot identify seed ID for {seqFile}!')
+
+
+def compile_core(core_options, other_options, seeds, inFol, cpus, outpath, silentOff, jobName):
     core_compilation_jobs = []
     (coreArgs, orthoCoreArgs, otherCoreArgs) = core_options
     (refspec, reuseCore, forceCore, pathArgs, debug) = other_options
     (outpath, hmmpath, corepath, searchpath, annopath) = pathArgs
+    pool = mp.Pool(cpus)
     begin = time.time()
     print('Preparing core compilation jobs...')
-    for seed in seeds:
-        seqFile = ('%s/%s' % (inFol, seed))
-        seqName = get_seed_name(seed)
-        if not os.path.exists('%s/core_orthologs/%s/hmm_dir/%s.hmm' % (outpath, seqName, seqName)) or forceCore == True:
-            seed_id = prepare_fn.identify_seed_id(seqFile, refspec, corepath, debug, silentOff)
-            core_compilation_jobs.append([seqFile, seqName, refspec, seed_id,
-                        reuseCore, forceCore, coreArgs, pathArgs, orthoCoreArgs,
-                        otherCoreArgs, debug])
+    core_job_file = '%s/%s_core_jobs.list' % (outpath, jobName)
+    if os.path.exists(core_job_file) and os.stat(core_job_file).st_size > 0:
+        print('... file contains jobs found (%s)' % core_job_file)
+        core_compilation_jobs = general_fn.read_pyobj_file(core_job_file)
+    else:
+        prepare_jobs = []
+        for seed in seeds:
+            prepare_jobs.append([seed, core_options, other_options, inFol, outpath, silentOff])
+        for _ in tqdm(pool.imap_unordered(create_core_jobs, prepare_jobs), total=len(prepare_jobs)):
+            core_compilation_jobs.append(_)
+        general_fn.save_pyobj(core_compilation_jobs, core_job_file)
     end = time.time()
-    print('==> Preparing finished in %s\n' % '{:5.3f}s'.format(end - begin))
+    print('==> %s jobs will be run. Preparing finished in %s' % (len(core_compilation_jobs), '{:5.3f}s'.format(end - begin)))
     if len(core_compilation_jobs) > 0:
-        pool = mp.Pool(cpus)
         core_runtime = []
         for _ in tqdm(pool.imap_unordered(core_fn.run_compile_core, core_compilation_jobs), total=len(core_compilation_jobs)):
             core_runtime.append(_)
@@ -87,7 +107,7 @@ def compile_core(core_options, other_options, seeds, inFol, cpus, outpath, silen
         return(out)
 
 
-def search_ortholog(options, seeds, inFol, cpu, outpath):
+def search_ortholog(options, seeds, inFol, outpath):
     (orthoArgs, otherArgs, pathArgs, refspec) = options
     (searchTaxa, cpus, debug, silentOff, noCleanup, force, append) = otherArgs
     ortho_runtime = []
@@ -95,6 +115,7 @@ def search_ortholog(options, seeds, inFol, cpu, outpath):
         begin = time.time()
         seqFile = [inFol + '/' + seed]
         seqName = get_seed_name(seed)
+        print('... %s' % seqName)
         if not os.path.exists('%s/%s.extended.fa' % (outpath, seqName)) or force == True:
             hamstr_out = ortho_fn.run_hamstr([seqName, refspec, pathArgs, orthoArgs, otherArgs])
             output_fn.write_hamstr(hamstr_out, outpath, seqName, force, append)
@@ -323,7 +344,7 @@ def main():
         otherCoreArgs = [cpus, debugCore, silentOff, noCleanup, force, append]
         core_options = [coreArgs, orthoCoreArgs, otherCoreArgs]
         other_options = [refspec, reuseCore, forceCore, pathArgs, debug]
-        core_runtime = compile_core(core_options, other_options, seeds, inFol, cpus, outpath, silentOff)
+        core_runtime = compile_core(core_options, other_options, seeds, inFol, cpus, outpath, silentOff, jobName)
         end = time.time()
         multi_core_time = '{:5.3f}'.format(end-start)
         print('==> Core compilation finished in %ss\n' % multi_core_time)
@@ -373,7 +394,7 @@ def main():
                         lowComplexityFilter, evalHmmer, hitLimit, scoreCutoff, aligner]
             otherArgs = [searchTaxa, cpus, debug, silentOff, noCleanup, force, append]
             ortho_options = [orthoArgs, otherArgs, pathArgs, refspec]
-            ortho_runtime = search_ortholog(ortho_options, seeds, inFol, cpus, outpath)
+            ortho_runtime = search_ortholog(ortho_options, seeds, inFol, outpath)
             end = time.time()
             multi_ortho_time = '{:5.3f}'.format(end-start)
             print('==> Ortholog search finished in %ss\n' % multi_ortho_time)
